@@ -4,7 +4,7 @@ from .commands.server import server as cmd_server
 
 
 @click.group()
-def run():
+def run():  # pragma: no cover
     pass
 
 
