@@ -14,12 +14,13 @@ from graphql.utilities.print_schema import (
     print_type as original_print_type,
 )
 
-from strawberry.types.types import FieldDefinition, TypeDefinition
+from strawberry.field import StrawberryField
+from strawberry.types.types import TypeDefinition
 
 from .schema import BaseSchema
 
 
-def print_federation_field_directive(field: Optional[FieldDefinition]) -> str:
+def print_federation_field_directive(field: Optional[StrawberryField]) -> str:
     if not field:
         return ""
 
@@ -43,14 +44,14 @@ def print_fields(type_, schema: BaseSchema) -> str:
     fields = []
 
     for i, (name, field) in enumerate(type_.fields.items()):
-        field_definition = strawberry_type.get_field(name) if strawberry_type else None
+        strawberry_field = strawberry_type.get_field(name) if strawberry_type else None
 
         fields.append(
             print_description(field, "  ", not i)
             + f"  {name}"
             + print_args(field.args, "  ")
             + f": {field.type}"
-            + print_federation_field_directive(field_definition)
+            + print_federation_field_directive(strawberry_field)
             + print_deprecated(field)
         )
 
